FeatureCollection

Struct FeatureCollection 

pub struct FeatureCollection {
    pub bbox: Option<Bbox>,
    pub features: Vec<Feature>,
    pub foreign_members: Option<JsonObject>,
}
Feature Collection Object

GeoJSON Format Specification  3.3

Examples

Serialization:

use geojson::FeatureCollection;
use geojson::GeoJson;

let feature_collection = FeatureCollection {
    bbox: None,
    features: vec![],
    foreign_members: None,
};

let serialized = feature_collection.to_string();
assert_eq!(serialized, r#"{"type":"FeatureCollection","features":[]}"#);

Deserializing a GeoJSON string into a FeatureCollection:

use geojson::{FeatureCollection, Feature, Geometry};

let geojson_str = r#"
{
  "type": "FeatureCollection",
  "features": [
    {
      "type": "Feature",
      "geometry": {
        "type": "Point",
        "coordinates": [-1.0, -2.0]
      }
    }
  ]
}"#;

let feature_collection = geojson_str
    .parse::<FeatureCollection>()
    .expect("valid FeatureCollection GeoJSON");

let expected = FeatureCollection::new([
    Feature::from(Geometry::new_point([-1.0, -2.0]))
]);
assert_eq!(feature_collection, expected);

Collect from an iterator:

use geojson::{Feature, FeatureCollection, Geometry};

let fc: FeatureCollection = (0..10)
    .map(|idx| -> Feature {
        let c = idx as f64;
        Geometry::new_point([1.0 * c, 2.0 * c, 3.0 * c]).into()
    })
    .collect();
assert_eq!(fc.features.len(), 10);

Fields

bbox: Option<Bbox>features: Vec<Feature>foreign_members: Option<JsonObject>

Foreign Members

GeoJSON Format Specification  6

See the crate-level foreign members documentation for details, including limitations on key names.

Implementations

Source

impl FeatureCollection

pub fn new(features: impl IntoIterator<Item = Feature>) -> Self

Construct a FeatureCollection from an iterator of Features (or things that can be turned Into a Feature)